/**
 * Copyright (c) 2013 David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */
package weather.gui;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;

import weather.Controller;


public class MainWindow extends JFrame
{
	private static final long serialVersionUID = 1L;

	private Controller mController;
	private PlottingPanel mPlottingPanel;

	@SuppressWarnings("unused")
	private DetailsDialog mDetailsDialog;

	@SuppressWarnings("unused")
	private ActionsDialog mActionsDialog;


	/**
	 * The main window for the weather application.
	 * @param controller
	 */
	public MainWindow(Controller controller)
	{
		mController = controller;

		mController.setMainWindow(this);

		//
		// Create the other GUI components.
		//
		mActionsDialog = new ActionsDialog(this, controller);
		mDetailsDialog = new DetailsDialog(this, controller);
		mPlottingPanel = new PlottingPanel(this, controller);

		getContentPane().add(mPlottingPanel);

		//
		// Catch the window closing event.
		//
		addWindowListener(new WindowAdapter()
			{
				@Override
				public void windowClosing(WindowEvent e)
				{
					mController.exit();
				}
			});

		//
		// Make the window visible.
		//
		pack();
		setVisible(true);
	}
}
